@@ -13,6 +13,10 @@ from conans.util.files import load
 
 # complex_search: With ORs and not filtering by not restricted settings
 COMPLEX_SEARCH_CAPABILITY = "complex_search"
-SERVER_CAPABILITIES = [COMPLEX_SEARCH_CAPABILITY, ]
+API_V2 = "api_v2"
+CHECKSUM_DEPLOY = "checksum_deploy"  # Only when v2
+REVISIONS = "revisions"  # Only when enabled in config, not by default look at server_launcher.py
+SERVER_CAPABILITIES = [COMPLEX_SEARCH_CAPABILITY, API_V2]
+
+__version__ = '1.7.0'
 
-__version__ = '1.6.1'
