@@ -4,13 +4,10 @@ from conans.client import packager
 from conans.client.client_cache import ClientCache
 from conans.client.cmd.export import _execute_export
 from conans.client.generators import write_generators
-from conans.client.generators.text import TXTGenerator
 from conans.client.importer import run_imports, run_deploy
 from conans.client.installer import ConanInstaller, call_system_requirements
-from conans.client.loader import ConanFileLoader
 from conans.client.manifest_manager import ManifestManager
 from conans.client.output import ScopedOutput, Color
-from conans.client.profile_loader import read_conaninfo_profile
 from conans.client.source import config_source_local, complete_recipe_sources
 from conans.client.tools import cross_building, get_cross_building_settings
 from conans.client.userio import UserIO
@@ -18,12 +15,10 @@ from conans.errors import NotFoundException, ConanException, conanfile_exception
 from conans.model.conan_file import get_env_context_manager
 from conans.model.ref import ConanFileReference, PackageReference
 from conans.paths import CONANFILE, CONANINFO, CONANFILE_TXT, BUILD_INFO
-from conans.util.files import save, rmdir, normalize, mkdir, load
+from conans.util.files import save, rmdir, normalize, mkdir
 from conans.util.log import logger
-from conans.client.graph.graph_manager import GraphManager
-from conans.client.graph.build_mode import BuildMode
+from conans.client.graph.graph_manager import load_deps_info
 from conans.client.graph.printer import print_graph
-from conans.client.graph.graph import BINARY_BUILD
 
 
 class ConanManager(object):
@@ -31,58 +26,16 @@ class ConanManager(object):
     business logic
     """
     def __init__(self, client_cache, user_io, runner, remote_manager,
-                 settings_preprocessor, recorder, registry):
+                 recorder, registry, graph_manager):
         assert isinstance(user_io, UserIO)
         assert isinstance(client_cache, ClientCache)
         self._client_cache = client_cache
         self._user_io = user_io
         self._runner = runner
         self._remote_manager = remote_manager
-        self._settings_preprocessor = settings_preprocessor
         self._recorder = recorder
         self._registry = registry
-
-    def _load_consumer_conanfile(self, conanfile_path, info_folder, output,
-                                 deps_info_required=False):
-        """loads a conanfile for local flow: source, imports, package, build
-        """
-        profile = read_conaninfo_profile(info_folder) or self._client_cache.default_profile
-        loader = self.get_loader(profile, local=True)
-        if conanfile_path.endswith(".py"):
-            conanfile = loader.load_conan(conanfile_path, output, consumer=True, local=True)
-        else:
-            conanfile = loader.load_conan_txt(conanfile_path, output)
-
-        _load_deps_info(info_folder, conanfile, required=deps_info_required)
-
-        return conanfile
-
-    def _load_install_conanfile(self, loader, reference_or_path):
-        """loads a conanfile for installation: install, info
-        """
-        if isinstance(reference_or_path, ConanFileReference):
-            conanfile = loader.load_virtual([reference_or_path])
-        else:
-            output = ScopedOutput("PROJECT", self._user_io.out)
-            if reference_or_path.endswith(".py"):
-                conanfile = loader.load_conan(reference_or_path, output, consumer=True)
-            else:
-                conanfile = loader.load_conan_txt(reference_or_path, output)
-        return conanfile
-
-    def get_loader(self, profile, local=False):
-        """ When local=True it means that the state is being recovered from installed files
-        conaninfo.txt, conanbuildinfo.txt, and only local methods as build() are being executed.
-        Thus, it is necessary to restore settings from that info, as configure() is not called,
-        being necessary to remove those settings that doesn't have a value
-        """
-        cache_settings = self._client_cache.settings.copy()
-        cache_settings.values = profile.settings_values
-        if local:
-            cache_settings.remove_undefined()
-        else:
-            self._settings_preprocessor.preprocess(cache_settings)
-        return ConanFileLoader(self._runner, cache_settings, profile)
+        self._graph_manager = graph_manager
 
     def export_pkg(self, reference, source_folder, build_folder, package_folder, install_folder, profile, force):
 
@@ -90,18 +43,16 @@ class ConanManager(object):
         if not os.path.exists(conan_file_path):
             raise ConanException("Package recipe '%s' does not exist" % str(reference))
 
-        loader = self.get_loader(profile)
-        conanfile = loader.load_virtual([reference], scope_options=True)
-        graph_builder = self._get_graph_builder(loader, self._recorder)
-        deps_graph = graph_builder.load_graph(conanfile, check_updates=False, update=False,
-                                              build_mode=None)
+        deps_graph, _, _ = self._graph_manager.load_graph(reference, None, profile,
+                                                          build_mode=None, check_updates=False, update=False,
+                                                          remote_name=None, recorder=self._recorder, workspace=None)
 
         # this is a bit tricky, but works. The root (virtual), has only 1 neighbor,
         # which is the exported pkg
         nodes = deps_graph.root.neighbors()
         conanfile = nodes[0].conanfile
         if install_folder and existing_info_files(install_folder):
-            _load_deps_info(install_folder, conanfile, required=True)
+            load_deps_info(install_folder, conanfile, required=True)
         pkg_id = conanfile.info.package_id()
         self._user_io.out.info("Packaging to %s" % pkg_id)
         pkg_reference = PackageReference(reference, pkg_id)
@@ -126,85 +77,10 @@ class ConanManager(object):
             packager.create_package(conanfile, pkg_id, source_folder, build_folder,
                                     dest_package_folder, install_folder, package_output, local=True)
 
-    @staticmethod
-    def _inject_require(conanfile, inject_require):
-        """ test_package functionality requires injecting the tested package as requirement
-        before running the install
-        """
-        require = conanfile.requires.get(inject_require.name)
-        if require:
-            require.conan_reference = require.range_reference = inject_require
-        else:
-            conanfile.requires(str(inject_require))
-        conanfile._user = inject_require.user
-        conanfile._channel = inject_require.channel
-
-    def _get_graph_builder(self, loader, action_recorder):
-        graph_builder = GraphManager(self._user_io.out, loader,
-                                     self._client_cache, self._registry, self._remote_manager,
-                                     action_recorder, workspace=None)
-        return graph_builder
-
-    def _get_deps_graph(self, reference, profile, check_updates, update, build_mode,
-                        remote_name):
-        loader = self.get_loader(profile)
-        conanfile = self._load_install_conanfile(loader, reference)
-        graph_builder = self._get_graph_builder(loader, self._recorder)
-        build_mode = BuildMode(build_mode, self._user_io.out)
-        deps_graph = graph_builder.load_graph(conanfile, check_updates, update,
-                                              build_mode=build_mode, remote_name=remote_name,
-                                              profile_build_requires=profile.build_requires)
-        return deps_graph, conanfile
-
-    def info_build_order(self, reference, profile, build_order, remote_name, check_updates):
-        deps_graph, _ = self._get_deps_graph(reference, profile, update=False,
-                                             check_updates=check_updates, build_mode=["missing"],
-                                             remote_name=remote_name)
-        result = deps_graph.build_order(build_order)
-        return result
-
-    def info_nodes_to_build(self, reference, profile, build_mode, remote_name, check_updates):
-        deps_graph, conanfile = self._get_deps_graph(reference, profile, update=False,
-                                                     check_updates=check_updates, build_mode=build_mode,
-                                                     remote_name=remote_name)
-        ret = []
-        for level in deps_graph.by_levels():
-            for node in level:
-                if node.binary == BINARY_BUILD:
-                    if node.conan_ref not in ret:
-                        ret.append(node.conan_ref)
-        return ret, self._get_project_reference(reference, conanfile)
-
-    def _get_project_reference(self, reference, conanfile):
-        if isinstance(reference, ConanFileReference):
-            project_reference = None
-        else:
-            project_reference = str(conanfile)
-
-        return project_reference
-
-    def info_get_graph(self, reference, profile, remote_name=None, check_updates=False, build_mode=None):
-        """ Fetch and build all dependencies for the given reference
-        @param reference: ConanFileReference or path to user space conanfile
-        @param remote: install only from that remote
-        """
-        deps_graph, conanfile = self._get_deps_graph(reference, profile,
-                                                     update=False, check_updates=check_updates,
-                                                     build_mode=build_mode, remote_name=remote_name)
-
-        return deps_graph, self._get_project_reference(reference, conanfile)
-
     def install_workspace(self, profile, workspace, remote_name, build_modes, update):
-        loader = self.get_loader(profile)
         references = [ConanFileReference(v, "root", "project", "develop") for v in workspace.root]
-        conanfile = loader.load_virtual(references)
-
-        graph_builder = GraphManager(self._user_io.out, loader,
-                                     self._client_cache, self._registry, self._remote_manager,
-                                     self._recorder, workspace=workspace)
-        build_mode = BuildMode(build_modes, self._user_io.out)
-        deps_graph = graph_builder.load_graph(conanfile, False, update, build_mode, remote_name,
-                                              profile.build_requires)
+        deps_graph, _, _ = self._graph_manager.load_graph(references, None, profile, build_modes,
+                                                          False, update, remote_name, self._recorder, workspace)
 
         output = ScopedOutput(str("Workspace"), self._user_io.out)
         output.highlight("Installing...")
@@ -213,14 +89,12 @@ class ConanManager(object):
         installer = ConanInstaller(self._client_cache, output, self._remote_manager,
                                    self._registry, recorder=self._recorder, workspace=workspace)
         installer.install(deps_graph, keep_build=False)
-
-        build_mode.report_matches()
         workspace.generate()
 
     def install(self, reference, install_folder, profile, remote_name=None, build_modes=None,
                 update=False, manifest_folder=None, manifest_verify=False,
-                manifest_interactive=False, generators=None, no_imports=False, inject_require=None,
-                install_reference=False, keep_build=False):
+                manifest_interactive=False, generators=None, no_imports=False, create_reference=None,
+                keep_build=False):
         """ Fetch and build all dependencies for the given reference
         @param reference: ConanFileReference or path to user space conanfile
         @param install_folder: where the output files will be saved
@@ -242,34 +116,23 @@ class ConanManager(object):
             generators = set(generators) if generators else set()
             generators.add("txt")  # Add txt generator by default
 
-        loader = self.get_loader(profile)
-        if not install_reference:
-            if isinstance(reference, ConanFileReference):  # is a create
-                loader.dev_reference = reference
-            elif inject_require:
-                loader.dev_reference = inject_require
-        conanfile = self._load_install_conanfile(loader, reference)
-        if inject_require:
-            self._inject_require(conanfile, inject_require)
-
-        graph_builder = self._get_graph_builder(loader, self._recorder)
-        build_mode = BuildMode(build_modes, self._user_io.out)
-        deps_graph = graph_builder.load_graph(conanfile, False, update, build_mode, remote_name,
-                                              profile.build_requires)
+        result = self._graph_manager.load_graph(reference, create_reference, profile,
+                                                build_modes, False, update, remote_name, self._recorder,
+                                                None)
+        deps_graph, conanfile, cache_settings = result
 
         if not isinstance(reference, ConanFileReference):
-            output = ScopedOutput(("%s (test package)" % str(inject_require)) if inject_require else "PROJECT",
+            output = ScopedOutput(("%s (test package)" % str(create_reference)) if create_reference else "PROJECT",
                                   self._user_io.out)
             output.highlight("Installing %s" % reference)
         else:
             output = ScopedOutput(str(reference), self._user_io.out)
             output.highlight("Installing package")
         print_graph(deps_graph, self._user_io.out)
-        build_mode.report_matches()
 
         try:
-            if cross_building(loader._settings):
-                b_os, b_arch, h_os, h_arch = get_cross_building_settings(loader._settings)
+            if cross_building(cache_settings):
+                b_os, b_arch, h_os, h_arch = get_cross_building_settings(cache_settings)
                 message = "Cross-build from '%s:%s' to '%s:%s'" % (b_os, b_arch, h_os, h_arch)
                 self._user_io.out.writeln(message, Color.BRIGHT_MAGENTA)
         except ConanException:  # Setting os doesn't exist
@@ -308,9 +171,10 @@ class ConanManager(object):
                 run_imports(conanfile, install_folder, output)
             call_system_requirements(conanfile, output)
 
-            if install_reference:
+            if not create_reference and isinstance(reference, ConanFileReference):
                 # The conanfile loaded is really a virtual one. The one with the deploy is the first level one
-                deploy_conanfile = deps_graph.inverse_levels()[1][0].conanfile
+                neighbours = deps_graph.root.neighbors()
+                deploy_conanfile = neighbours[0].conanfile
                 if hasattr(deploy_conanfile, "deploy") and callable(deploy_conanfile.deploy):
                     run_deploy(deploy_conanfile, install_folder, output)
 
@@ -324,7 +188,7 @@ class ConanManager(object):
         """
         output = ScopedOutput("PROJECT", self._user_io.out)
         # only infos if exist
-        conanfile = self._load_consumer_conanfile(conanfile_path, info_folder, output)
+        conanfile = self._graph_manager.load_consumer_conanfile(conanfile_path, info_folder, output)
         conanfile_folder = os.path.dirname(conanfile_path)
         if conanfile_folder != source_folder:
             output.info("Executing exports to: %s" % source_folder)
@@ -340,9 +204,8 @@ class ConanManager(object):
         """
 
         output = ScopedOutput("PROJECT", self._user_io.out)
-        conanfile = self._load_consumer_conanfile(conan_file_path, info_folder,
-                                                  output, deps_info_required=True)
-
+        conanfile = self._graph_manager.load_consumer_conanfile(conan_file_path, info_folder, output,
+                                                                deps_info_required=True)
         run_imports(conanfile, dest_folder, output)
 
     def local_package(self, package_folder, conanfile_path, build_folder, source_folder,
@@ -351,8 +214,8 @@ class ConanManager(object):
             raise ConanException("Cannot 'conan package' to the build folder. "
                                  "--build-folder and package folder can't be the same")
         output = ScopedOutput("PROJECT", self._user_io.out)
-        conanfile = self._load_consumer_conanfile(conanfile_path, install_folder, output,
-                                                  deps_info_required=True)
+        conanfile = self._graph_manager.load_consumer_conanfile(conanfile_path, install_folder, output,
+                                                                deps_info_required=True)
         packager.create_package(conanfile, None, source_folder, build_folder, package_folder,
                                 install_folder, output, local=True, copy_info=True)
 
@@ -369,8 +232,8 @@ class ConanManager(object):
             # Append env_vars to execution environment and clear when block code ends
             output = ScopedOutput(("%s (test package)" % test) if test else "Project",
                                   self._user_io.out)
-            conan_file = self._load_consumer_conanfile(conanfile_path, install_folder, output,
-                                                       deps_info_required=True)
+            conan_file = self._graph_manager.load_consumer_conanfile(conanfile_path, install_folder,
+                                                                     output, deps_info_required=True)
         except NotFoundException:
             # TODO: Auto generate conanfile from requirements file
             raise ConanException("'%s' file is needed for build.\n"
@@ -412,36 +275,6 @@ class ConanManager(object):
             raise ConanException("Unable to build it successfully\n%s" % '\n'.join(trace[3:]))
 
 
-def _load_deps_info(current_path, conanfile, required):
-
-    def get_forbidden_access_object(field_name):
-        class InfoObjectNotDefined(object):
-            def __getitem__(self, item):
-                raise ConanException("self.%s not defined. If you need it for a "
-                                     "local command run 'conan install'" % field_name)
-            __getattr__ = __getitem__
-
-        return InfoObjectNotDefined()
-
-    if not current_path:
-        return
-    info_file_path = os.path.join(current_path, BUILD_INFO)
-    try:
-        deps_cpp_info, deps_user_info, deps_env_info = TXTGenerator.loads(load(info_file_path))
-        conanfile.deps_cpp_info = deps_cpp_info
-        conanfile.deps_user_info = deps_user_info
-        conanfile.deps_env_info = deps_env_info
-    except IOError:
-        if required:
-            raise ConanException("%s file not found in %s\nIt is required for this command\n"
-                                 "You can generate it using 'conan install'"
-                                 % (BUILD_INFO, current_path))
-        conanfile.deps_cpp_info = get_forbidden_access_object("deps_cpp_info")
-        conanfile.deps_user_info = get_forbidden_access_object("deps_user_info")
-    except ConanException:
-        raise ConanException("Parse error in '%s' file in %s" % (BUILD_INFO, current_path))
-
-
 def existing_info_files(folder):
     return os.path.exists(os.path.join(folder, CONANINFO)) and  \
            os.path.exists(os.path.join(folder, BUILD_INFO))
